﻿// Copyright (C) 2025 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only

#include <QtQuickTest/private/quickforandroidtest_p.h>

QUICK_FOR_ANDROID_TEST_MAIN(tst_qtquickview_signallistener)
